"""Demonstrate the basic functionality of the Geodise Compute Toolbox for Jython

To invoke this script in the jython environment type;
    >>import demo_compute
or to call subsequently
    >>reload(demo_compute)
"""

#   Copyright 2004 Geodise Project, University of Southampton
#   Graeme Pound $Date: 2005/05/10 10:10:24 $
#   $Revision: 1.6 $
#   Geodise Compute Toolbox for Jython

import os
import gdcompute
from gdcompute import *

######################################################################
# Print the introduction 
######################################################################


print ('  Geodise Compute Toolkit test script.') 
print (' ')
print ('  This test script will:')
print ('  (1) Query user credentials and create a proxy certificate')
print ('  (2) Create a remote directory and transfer a script to that directory')
print ('  (3) Alter the file permissions of the script and execute it')
print ('  (4) Retrieve the output of the job')
print ('  (5) Remove the remote files and directories')
print ('  (6) Delete the proxy certificate')
print (' ')
print ('  Press return to continue')

raw_input('>>> ')
print (' ')

######################################################################
# Set up the demo variables
######################################################################
# The Globus server upon which to run the shell script. Note that the
# certificate subject line (returned by gd_certinfo) must map to a user
# account on the Globus server.
GLOBUSSERVER = 'escience-dept2.sesnet.soton.ac.uk'
print('  Enter the name of the Globus GT2 server that you wish to use?')
print('    Note that you must have authorisation to access the GRAM')
print('    and GridFTP services on this server.')
servername = raw_input('>>> ')
if servername:
    GLOBUSSERVER = servername
else:
    GLOBUSSERVER

print (' ')
print ">>> GLOBUSSERVER = '"+GLOBUSSERVER+"'"

# The name of the directory on the Globus server
DIRNAME = 'mdemo/'
# Locate the directory containing the shell script
SCRIPTDIR = os.path.dirname( __file__ )+os.sep
OUTPUTDIR = os.getcwd()+os.sep

print ">>> DIRNAME = '"+DIRNAME+"'"
print ">>> SCRIPTDIR = '"+SCRIPTDIR+"'"
print ">>> OUTPUTDIR = '"+OUTPUTDIR+"'"

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')

######################################################################
# Create a proxy certificate
######################################################################
print ('  (1) Query user credentials and create a proxy certificate')

print(' ')
#Query the user's certificate
print ("  (1.1) Print information about the user's certificate")
print (' ')
print ('>>> subject = gd_certinfo() ')
print ('>>> print; print subject ')
subject = gd_certinfo()
print (' ')
print subject 
print (' ') 

# Create a Globus proxy certificate for GSI authentication
print ('  (1.2) Create a Globus proxy certificate for GSI authentication')
print (' ')
print ('>>> gd_createproxy()')
gd_createproxy()
print (' ')

# Return information about the proxy certificate
print ('  (1.3) Print information about the proxy certificate')
print (' ')
print ('>>> gd_proxyinfo() ')
gd_proxyinfo()

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')

######################################################################
# Put the remote files
######################################################################
print ('  (2) Create a remote directory and transfer a script to that directory')

print(' ')
print ('  (2.1) Create a remote directory "'+DIRNAME+'"')
print(">>> gd_makedir(GLOBUSSERVER, DIRNAME)")
gd_makedir(GLOBUSSERVER, DIRNAME)

print(' ')
print ('  (2.2) Printing the shell script "jythonDemo.sh" ')
print(">>> open(SCRIPTDIR+'jythonDemo.sh').read()")
print open(SCRIPTDIR+'jythonDemo.sh').read()


# GridFTP the demo shell script from the local directory to the users home
# directory on GLOBUSSERVER 
print(' ')
print('  (2.3) Transfering jythonDemo.sh to Globus server using GridFTP')
print(">>> gd_putfile(GLOBUSSERVER, SCRIPTDIR+'jythonDemo.sh', DIRNAME+'jythonDemo.sh')")
gd_putfile(GLOBUSSERVER,SCRIPTDIR+'jythonDemo.sh',DIRNAME+'jythonDemo.sh')

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')

######################################################################
# Run the demonstration script
######################################################################
print ('  (3) Alter the file permissions of the script and execute it')

print(' ')
print ('  (3.1) Modify the permissions on the shell script')
# Modify the permissions on the shell script, currently there is no API to
# perform chmod in the file transfer so this is a work around.
print ">>> jobhandle = gd_jobsubmit('&(executable=/bin/chmod) (arguments = 700 ", DIRNAME+"jythonDemo.sh)',GLOBUSSERVER)"
jobhandle = gd_jobsubmit('&(executable=/bin/chmod)(arguments = 700 '+DIRNAME+'jythonDemo.sh)',GLOBUSSERVER)
gd_jobpoll(jobhandle)


print(' ')
print ('  (3.2) Execute the shell script')
# The RSL string describes the GRAM job to be submitted to GLOBUSSERVER, the
# stdout and stderr are redirected to file. Note that GRAM will append
# existing files of the same name with output
RSLstring = '&(executable='+DIRNAME+'jythonDemo.sh)(stdout='+DIRNAME+'stdout.out)(stderr='+DIRNAME+'stderr.out)'
print(">>> RSL = '"+RSLstring+"'")
# Submit the job to the GRAM gatekeeper on GLOBUSSERVER
print(">>> jobHandle = gd_jobsubmit(RSL, GLOBUSSERVER)")
print('>>> print; print jobhandle')
jobhandle = gd_jobsubmit(RSLstring,GLOBUSSERVER)
print
print jobhandle

# Terminate the GRAM job
#gd_jobkill(jobHandle)

print(' ')
print('  (3.3) Polling jobhandle until completion (or up to 1min)')
print('>>> gd_jobpoll(jobhandle, 5, 60)')
# Poll the GRAM job every 5 seconds for a maximum of one minute
gd_jobpoll(jobhandle, 5, 60)

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')
######################################################################
# Get the output files
######################################################################
print ('  (4) Retrieve the output of the job')
print(' ')
print('  (4.1) Retrieving output from the Globus server using GridFTP')
# Retrieve the files
print(">>> gd_getfile(GLOBUSSERVER, DIRNAME+'stdout.out', OUTPUTDIR+'stdout.out')")
gd_getfile(GLOBUSSERVER,DIRNAME+'stdout.out',OUTPUTDIR+'stdout.out')
print(">>> gd_getfile(GLOBUSSERVER, DIRNAME+'stderr.out', OUTPUTDIR+'stderr.out')")
gd_getfile(GLOBUSSERVER,DIRNAME+'stderr.out',OUTPUTDIR+'stderr.out')


print(' ')
print('  (4.2) Display the output of the job')  
# Display the output
print(">>> print open(OUTPUTDIR+'stdout.out').read()")
outfile = open(OUTPUTDIR+'stdout.out')
print outfile.read()
outfile.close()

print(">>> print open(OUTPUTDIR+'stderr.out').read()")
errfile = open(OUTPUTDIR+'stderr.out')
print errfile.read()
errfile.close()


print(' ')
print('  (4.3) Delete the local files')  
# Delete local files
print(">>> os.remove(OUTPUTDIR+'stdout.out')")
try:
    os.remove(OUTPUTDIR+'stdout.out')
except:
    pass

print(">>> os.remove(OUTPUTDIR+'stdout.out')")
try:
    os.remove(OUTPUTDIR+'stderr.out')
except:
    pass

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')
######################################################################
# Delete the remote files 
######################################################################
print ('  (5) Remove the remote files and directories')

print (' ')
# Delete remote files
print ('  (5.1) Delete the remote files using GridFTP')
print(">>> gd_rmfile(GLOBUSSERVER,DIRNAME+'stdout.out')")
gd_rmfile(GLOBUSSERVER,DIRNAME+'stdout.out')
print(">>> gd_rmfile(GLOBUSSERVER,DIRNAME+'stderr.out')")
gd_rmfile(GLOBUSSERVER,DIRNAME+'stderr.out')
print(">>> gd_rmfile(GLOBUSSERVER,DIRNAME+'jythonDemo.sh')")
gd_rmfile(GLOBUSSERVER,DIRNAME+'jythonDemo.sh')


print (' ')
print ('  (5.1) Delete the remote directory using GridFTP')
# Delete remote directory
print('>>> gd_rmdir(GLOBUSSERVER, DIRNAME)')
gd_rmdir(GLOBUSSERVER, DIRNAME)

print (' ')
print ('  Press return to continue')
raw_input('>>> ')
print (' ')
######################################################################
# Destroy the proxy certificate
######################################################################

print ('  (6) Delete the proxy certificate')
print (' ')
print('>>> gd_destroyproxy()')
gd_destroyproxy()

print (' ')
print ('  Script complete')
