"""Demonstrate the basic functionality of the Geodise Database Toolbox for Jython

To invoke this script in the jython environment type;
    >>import demo_db
or to call subsequently
    >>reload(demo_db)
"""

#   Copyright 2005 Geodise Project, University of Southampton
#   Jasmin Wason $Date: 2005/09/01 11:02:57 $
#   $Revision: 1.5 $
#   Geodise Database Toolbox for Jython

import sys
import os
import os.path

from gddatabase import *
from gdcompute import gd_createproxy
from java.text import SimpleDateFormat
from java.util import Date

fs = os.sep
fileStr = 'file';
stdStr = 'standard';
varStr = 'var';
# Get the location of the Geodise database toolbox
fpath = __file__
dbpath = os.path.split(fpath)[0]
# Set location of test file paths
default_file = dbpath + fs + 'TestFile.txt'
retrieve_path = os.getcwd() + fs + 'TestFile2.txt'

print 'Geodise Database Toolbox test script. Creating proxy certificate.'
gd_createproxy()
print ' '
print 'This test script will:'
print '(1) Create a datagroup with gd_datagroup.'
print '(2) Archive a file with metadata and add it to the datagroup with gd_archive.'
print '(3) Query the file\'s metadata with gd_query.'
print '(4) Retrieve the file with gd_retrieve.'
print '(5) Archive a dictionary and add it to the datagroup with gd_archive.'
print '(6) Query the dictionary with gd_query.'
print '(7) Retrieve the dictionary to the workspace with gd_retrieve.'
print ' '
s = raw_input('Press return to continue')

print
print '(1) Creating a new datagroup'
print
print 'dgmetadata = {\'standard\': {\'comment\': \'This is a comment about a test datagroup\'}}'
dgmetadata = {'standard': {'comment': 'This is a comment about a test datagroup'}}

# Uncomment to give another user access to the datagroup metadata
# dgmetadata['access'] = {'users': ['bob']}

print 'dg_id1 = gd_datagroup (\'A test datagroup\', dgmetadata)'
dg_id1 = gd_datagroup ('A test datagroup', dgmetadata)
print
s = raw_input('Press return to continue')

print
print '(2.1) Creating file metadata using a dictionary'

print 'metadata = {}'
print 'metadata[\'standard\'] = {\'comment\': \'Comment about file\'}'
metadata = {}
metadata['standard'] = {'comment': 'Comment about file'}

print 'metadata[\'text\'] = \'some test text data\''
metadata['text'] = 'some test text data'
print 'metadata[\'num\'] = 43'
metadata['num'] = 43
print 'metadata[\'mylist\'] = [\'text\', 5, \'more text\']'
metadata['mylist'] = ['text', 5, 'more text']
print 'metadata[\'a\'] = {\'b\': 0.03, \'c\': [0.9, 1.4]}'
metadata['a'] = {'b': 0.03, 'c': [0.9, 1.4]}

# Uncomment to give another user access to the file and metadata
# dgmetadata['access'] = {'users': ['bob']}

print
s = raw_input('Press return to continue')

print
print '(2.2) Archiving file with the metadata and adding it to the datagroup'
print
print 'default_file = ' + default_file
print 'fileID = gd_archive (default_file, metadata, dg_id1)'
fileID = gd_archive (default_file, metadata, dg_id1)
print '\'' + fileID + '\''
print
s = raw_input('Press return to continue')

print
print '(3) Querying to find metadata about file where standard.ID = ' + fileID

print 'QResults = gd_query (\'' + stdStr + '.ID = ' + fileID + '\')'
QResults = gd_query (stdStr + '.ID = ' + fileID)
print 'gd_display(QResults)'
gd_display(QResults)
print
s = raw_input('Press return to continue')

print
print '(4) Retrieving file to local file system'
print ('location = gd_retrieve (QResults[0][\'standard\'][\'ID\'], \'' 
+ retrieve_path + '\')')
location = gd_retrieve (QResults[0]['standard']['ID'], retrieve_path)
print '\'' + location + '\''
print
s = raw_input('Press return to continue')

print
print '(5) Archiving a dictionary and adding it to the datagroup'
formatter = java.text.SimpleDateFormat('yyyy-MM-dd');
today = java.util.Date();
date = formatter.format(today);
print 'v = {\'text\': \'test string\'}'
v = {'text': 'test string'}
print 'v[\'details\'] = {\'five\': 5, \'date\': ' + date + '}'
v['details'] = {'five': 5, 'date': date}
print
print 'varID = gd_archive (v, None, dg_id1)'
varID = gd_archive (v, None, dg_id1)
print
s = raw_input('Press return to continue')

userID = QResults[0]['standard']['userID']

userID = QResults[0]['standard']['userID']

print
print '(6) Querying to find variables where standard.userID = ' + userID +\
      ' and details.five = 5 and standard.archiveDate >= ' + date

print ('results = gd_query (\'standard.userID = ' + userID + 
       ' & details.five = 5 & standard.archiveDate >= ' 
       + date + '\', \'' + varStr + '\')')
results = gd_query('standard.userID = ' + userID +
          ' & details.five=5 & standard.archiveDate >= ' + date, varStr)
print 'gd_display(results[0])'
gd_display(results[0])
print
s = raw_input('Press return to continue')

print
print '(7) Retrieving dictionary with ID varID to variable c.'
print 'c = gd_retrieve(varID)'
c = gd_retrieve(varID)
print c

print
print 'End of demo_db.'
