"""Demonstrate the basic functionality of the Geodise XML Toolbox for Jython

To invoke this script in the jython environment type;
    >>import demo_xml
or to call subsequently
    >>reload(demo_xml)
"""

# Copyright (C) 2005, Geodise Project, University of Southampton
# Geodise XML Toolbox for Jython
# Marc Molinari <m.molinari@soton.ac.uk>
# $Date: 2005/05/05 15:41:58 $
# $Revision: 1.3 $

# import XML toolbox functionality from gdxml
from gdxml import *

# ----------------------------------------------------
# utility function definitions
# ----------------------------------------------------
def _presskey():
  print ' '
  s = raw_input(' ### Press return to continue')
  print ' '
  return
# ----------------------------------------------------

# ----------------------------------------------------
# main code
# ----------------------------------------------------

print '------------------------------------------------------------------'
print ' '
print 'This is the Geodise XML Toolbox for Jython demo script demo_xml.py'
print ' '
print 'This demo script will show how to use the commands to convert'
print 'Python data into XML format and vice versa.'
_presskey()
print '------------------------------------------'
print 'First, we need to import the relevant methods:'
print ' '
print ' >>> from gdxml import xml_format'
print ' >>> from gdxml import xml_parse'
print ' >>> from gdxml import xml_save'
print ' >>> from gdxml import xml_load'
_presskey()
print '------------------------------------------'
print 'Then let\'s create a new data structure ... '
print ' '
print ' >>> data = {\'project\': {}}'
print ' >>> data[\'project\'][\'comment\']    = \'This is a project comment.\' '
print ' >>> data[\'project\'][\'name\']       = \'myproject\' '
print ' >>> data[\'project\'][\'parameters\'] = {\'alpha\':0.5, \'beta\':0.79, \'pi\':3.1415} '

data = {'project': {}}
data['project']['comment'] = 'This is a project comment.'
data['project']['name']    = 'myproject'
data['project']['parameters'] = {'alpha':0.5, 'beta':0.79, 'pi':3.1415}

_presskey()
print '------------------------------------------'
print '... and convert this data structure into XML format and display it:'
print ' '
print ' >>> xmlstring = xml_format( data )'
print ' >>> print( xmlstring )'
print ' '
xmlstring = xml_format( data )
print ("\n" + xmlstring)
_presskey()
print '------------------------------------------'
print 'Alternatively we can convert it into XML without the attributes:'
print ' '
print ' >>> xmlstring_noatt = xml_format( data, attswitch=\'off\' )'
print ' >>> print( xmlstring_noatt )'
print ' '
xmlstring_noatt = xml_format( data, attswitch='off' )
print( xmlstring_noatt )
_presskey()

print '... or give it a different root-level name, e.g. MyDataStructure'
print ' '
print ' >>> xmlstring_noatt_name = xml_format( data, attswitch=\'off\', name=\'MyDataStructure\' )'
print ' >>> print( xmlstring_noatt_name )'
print ' '
xmlstring_noatt_name = xml_format( data, attswitch='off', name='MyDataStructure' )
print( xmlstring_noatt_name )
_presskey()

print '------------------------------------------'
print 'You can save this data directly to a file in XML format with the '
print 'xml_save() command and reload it with the xml_load() command.'
print ' '
print ' >>> xml_save( \'mydata.xml\', data )'
print ' '
try:
  xml_save( 'mydata.xml', data )
  print 'I have just created this file successfully in the current working directory.'
except:
  print ('Oops: Cannot write file in current directory.')
_presskey()

print '------------------------------------------'
print 'With this toolbox you can also convert XML strings directly into data trees, e.g.'
print ' '
print ' >>> xmlstr = \'<root><mydata><alpha>1</alpha><alpha>2</alpha></mydata></root>\''
print ' >>> alphadata = xml_parse( xmlstr ) '
print ' '
xmlstr = '<root><mydata><alpha>1</alpha><alpha>2</alpha></mydata></root>'
alphadata = xml_parse( xmlstr )
print(' alphadata = ')
print(alphadata)
_presskey()

print '--------------------------------------------------------------------'
print '  Script demo_xml() for the XML Toolbox for Jython has finished.'
print '--------------------------------------------------------------------'
